"""
SPAD Language enumeration module.

This module defines the available languages for SPAD (Spiritual Principle A Day) meditations.
"""

from enum import Enum


class SpadLanguage(Enum):
    """
    Enumeration of supported languages for SPAD meditations.

    Each enum value represents a language for which SPAD meditations can be fetched.
    """

    English = 1
